package cn.com.infosec.crypto.params;

import cn.com.infosec.crypto.CipherParameters;
import java.math.BigInteger;

public class DHParameters implements CipherParameters {
   private static final int DEFAULT_MINIMUM_LENGTH = 160;
   private BigInteger g;
   private BigInteger p;
   private BigInteger q;
   private BigInteger j;
   private int m;
   private int l;
   private DHValidationParameters validation;

   public DHParameters(BigInteger p, BigInteger g) {
      this(p, g, (BigInteger)null, 160, 0, (BigInteger)null, (DHValidationParameters)null);
   }

   public DHParameters(BigInteger p, BigInteger g, BigInteger q) {
      this(p, g, q, 160, 0, (BigInteger)null, (DHValidationParameters)null);
   }

   public DHParameters(BigInteger p, BigInteger g, BigInteger q, int l) {
      this(p, g, q, l, l, (BigInteger)null, (DHValidationParameters)null);
   }

   public DHParameters(BigInteger p, BigInteger g, BigInteger q, int m, int l) {
      this(p, g, q, m, l, (BigInteger)null, (DHValidationParameters)null);
   }

   public DHParameters(BigInteger p, BigInteger g, BigInteger q, BigInteger j, DHValidationParameters validation) {
      this(p, g, q, 160, 0, j, validation);
   }

   public DHParameters(BigInteger p, BigInteger g, BigInteger q, int m, int l, BigInteger j, DHValidationParameters validation) {
      this.m = 160;
      if (l != 0 && m > l) {
         throw new IllegalArgumentException("l value must be greater than m value if provided");
      } else {
         this.g = g;
         this.p = p;
         this.q = q;
         this.m = m;
         this.l = l;
         this.j = j;
         this.validation = validation;
      }
   }

   public BigInteger getP() {
      return this.p;
   }

   public BigInteger getG() {
      return this.g;
   }

   public BigInteger getQ() {
      return this.q;
   }

   public BigInteger getJ() {
      return this.j;
   }

   public int getM() {
      return this.m;
   }

   public int getL() {
      return this.l;
   }

   public DHValidationParameters getValidationParameters() {
      return this.validation;
   }

   public boolean equals(Object obj) {
      if (!(obj instanceof DHParameters)) {
         return false;
      } else {
         DHParameters obj1 = (DHParameters)obj;
         if (this.getQ() != null) {
            if (!this.getQ().equals(obj1.getQ())) {
               return false;
            }
         } else if (obj1.getQ() != null) {
            return false;
         }

         return obj1.getP().equals(this.p) && obj1.getG().equals(this.g);
      }
   }

   public int hashCode() {
      int var1 = this.getP().hashCode() ^ this.getG().hashCode();
      int var2;
      if (this.getQ() != null) {
         var2 = this.getQ().hashCode();
      } else {
         var2 = 0;
      }

      return var1 ^ var2;
   }
}
